@@ -3,7 +3,6 @@ use strict;
 use warnings;
 
 use Math::Geometry::Construction;
-use Math::Geometry::Construction::Derivate::IntersectionLineLine;
 
 my $construction = Math::Geometry::Construction->new
     (width  => 500, height => 300);
@@ -21,9 +20,8 @@ my $l2 = $construction->add_line;
 $l2->add_support($p3);
 $l2->add_support($p4);
 
-my $i1 = $construction->add_object
-    ('Math::Geometry::Construction::Derivate::IntersectionLineLine',
-     input => [$l1, $l2]);
+my $i1 = $construction->add_derivate('IntersectionLineLine',
+				     input => [$l1, $l2]);
 my $p5 = $i1->create_derived_point
     (point_selector => ['indexed_point', [0]],
      label          => 'S',
